fn fake_doc_items(tcx: TyCtxt<'_>, _: LocalCrate) -> Vec<DefId>Expand description
Traverse and collect the fake doc items in the current crate
fn fake_doc_items(tcx: TyCtxt<'_>, _: LocalCrate) -> Vec<DefId>Traverse and collect the fake doc items in the current crate